<?php

namespace App\Http\Controllers;

use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;

class UsersController extends Controller
{
    public function index() {
        $defaultExpiryDate = now()->addYears(3)->toDateString();
        return view('form', compact('defaultExpiryDate'));
    }

    public function submitForm(Request $request) {
        $validator = Validator::make($request->all(), [
            'name' => 'required|string',
            'company_name' => 'required|string',
            'photo' => 'required|image|mimes:jpeg,png,jpg,gif|max:2048',
            'email' => 'required|email',
            'mobile_number' => 'required|string',
            'facebook_link' => 'nullable|string',
            'instagram_link' => 'nullable|string',
            'short_description' => 'nullable|string',
            'expiry_date' => 'required|date',
            'status' => 'required|in:active,inactive',
            'is_approved' => 'nullable|boolean',
        ]);
        if ($validator->fails()) {
            return response()->json(['error' => $validator->errors()], 422);
        }

        // dd($request->input('expiry_date'));
        $data = new User();
        $data->name = $request->input('name');
        $data->company_name = $request->input('company_name');

        if ($request->hasFile('photo')) {
            $file = $request->file('photo');
            $filename = uniqid().'.'.$file->getClientOriginalExtension();
            $file->move(storage_path('app/public/photos'), $filename);
            $data->photo = $filename;
        }
        if ($request->hasFile('logo')) {
            $file = $request->file('logo');
            $filename = uniqid().'.'.$file->getClientOriginalExtension();
            $file->move(storage_path('app/public/logo'), $filename);
            $data->logo = $filename;
        }

        $data->email = $request->input('email');
        $data->mobile_number = $request->input('mobile_number');
        $data->facebook_link = $request->input('facebook_link');
        $data->instagram_link = $request->input('instagram_link');
        $data->short_description = $request->input('short_description');
        $data->expiry_date = $request->input('expiry_date');
        $data->status = $request->input('status');
        $data->is_approved = $request->input('is_approved');

        $data->save();

        return redirect()->back()->with('status',
            'Thank you for filling up the form. You will receive the details via email or phone shortly.');

    }
}
